/*

------------------------------------------------------------------------------

A license is hereby granted to reproduce this software source code and
to create executable versions from this source code for personal,
non-commercial use.  The copyright notice included with the software
must be maintained in all copies produced.

THIS PROGRAM IS PROVIDED "AS IS". THE AUTHOR PROVIDES NO WARRANTIES
WHATSOEVER, EXPRESSED OR IMPLIED, INCLUDING WARRANTIES OF
MERCHANTABILITY, TITLE, OR FITNESS FOR ANY PARTICULAR PURPOSE.  THE
AUTHOR DOES NOT WARRANT THAT USE OF THIS PROGRAM DOES NOT INFRINGE THE
INTELLECTUAL PROPERTY RIGHTS OF ANY THIRD PARTY IN ANY COUNTRY.

Copyright (c) 1994-2008, John Conover, All Rights Reserved.

Comments and/or bug reports should be addressed to:

    john@email.johncon.com (John Conover)

------------------------------------------------------------------------------

white_sound.c is for generating white noise directly to the sound card.

The amplitude is read from stdin, as an EOL terminated record, The
amplitude must be greater than zero, and less than or equal to unity;
unity is 0 dBFS.

The default, for a null record, -15 dBFS, (with instantaneous peaks of
-13 dBFS, i.e., 7136.)

Since there is an even probability of an element in the white noise
time series of any integer between 0 and 32767, inclusive, the RMS
would be:

    Vo^2 = (0^2 + 1^2 + 2^2 + ... + 32767^2) / 32768

But the sum is 11726513487871, (from tsintegers(1), tsmath(1), and,
tsintegrate(1)):

    Vo = 18917.31459536393824101181

Which is the root mean square of white noise with peaks of 32767, with
an even probability of any number between 0 and 32767, inclusive.

For an RMS value of -15 dBFS:

    Va = (32767 / sqrt (2)) / pow (10, 15 / 20)

Which is:

    4120.23211904207445243938

And, the multiplyer:

    4120.23211904207445243938 / 18917.31459536393824101181

Is:

    0.21780216733572844168

$Revision: 0.0$
$Date: 2008/06/29 06:01:43 $
$Id: white_sound.c,v 1.4 2008/06/29 06:01:43 john Exp john $
$Log: white_sound.c,v $
Revision 0.0  2008/02/18 19:36:00  john
Initial version


*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <unistd.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <limits.h>
#include <sys/ioctl.h>
#include <sys/soundcard.h>

#ifdef __STDC__

#include <float.h>

#endif

static char rcsid[] = "$Id: white_sound.c,v 0.0 2008/06/29 06:01:43 john Exp john $"; /* program version */
static char copyright[] = "Copyright (c) 1994-2008, John Conover, All Rights Reserved"; /* the copyright banner */

#define BUFLEN BUFSIZ /* i/o buffer size */

#define TOKEN_SEPARATORS "," /* record field separators */
#define WS_SEPARATORS " \t\n\r\b,;:" /* file record field separators */

#ifdef __STDC__

static const char *help_message[] = /* help message index array */

#else

static char *help_message[] = /* help message index array */

#endif

{
    "\n",
    "Generate White Noise Directly to the Sound Card\n",
    "Usage: white_sound [-d device] [-i infilename] [-v]\n",
    "    -d device, sound device, (/dev/dsp)\n",
    "    -i infilename, input filename, (stdin)\n",
    "    -v, print the program's version information\n"
};

#ifdef __STDC__

static const char *error_message[] = /* error message index array */

#else

static char *error_message[] = /* error message index array */

#endif

{
    "No error\n",
    "Error in program argument(s)\n",
    "Error opening sound device\n",
    "Error setting sample format\n",
    "Error setting number of channels\n",
    "Error setting sample rate\n",
    "Error writing to sound device\n",
    "Error closing sound device\n",
    "Error overflow buffer\n",
    "Error getting status of input file\n",
    "Error selecting input file\n",
    "Error opening input file\n",
    "Error closing input file\n"
};

#define NOERROR 0 /* error values, one for each index in the error message array */
#define EARGS 1
#define EOPEN 2
#define EIOF 3
#define EION 4
#define EIOS 5
#define EWRITE 6
#define ECLOSE 7
#define EOVRFL 8
#define EISTAT 9
#define EISEL 10
#define EIOPEN 11
#define EICLOSE 12

#ifdef __STDC__

static void print_message (int retval); /* print any error messages */
static int strtoken (char *string, char *parse_array, char **parse, const char *delim); /* parse a record based on sequential delimiters */
static int white_gen (char *device, int infile, double amplitude); /* generate a white noise through the sound card */

#else

static void print_message (); /* print any error messages */
static int strtoken ();  /* parse a record based on sequential delimiters */
static int white_gen (); /* generate a white noise through the sound card */

#endif

static int sample_rate = 44100; /* sound sample rate */

char sound_device[] = "/dev/dsp"; /* sound device */

#ifdef __STDC__

int main (int argc, char *argv[])

#else

int main (argc, argv)
int argc;
char *argv[];

#endif

{
    char *device = sound_device, /* sound device */
         inchar, /* character from input file */
         inbuffer[BUFLEN + 1], /* input read buffer */
         parsebuffer[BUFLEN], /* parsed i/o buffer */
         *in_name = (char *) 0, /* input file name */
         *token[BUFLEN / 2], /* reference to tokens in parsed i/o buffer */
         *ref, /* character reference in input buffer */
         *sentinel = &inbuffer[BUFLEN]; /* reference to sentinel character in input buffer */

    int retval = NOERROR, /* return value, assume no error */
        fields, /* number of fields */
        infile = STDIN_FILENO, /* input file descriptor */
        c; /* command line switch */

    double amplitude = (double) 1.0, /* amplitude to generate, defaults to -15 dBFS */
           tmp; /* temporary double storage */

    ssize_t cnt_in = 0; /* count of characters read */

    *sentinel = '\0'; /* sentinel character in input buffer */

    while ((retval == NOERROR) && ((c = getopt (argc, argv, "d:i:v")) != EOF)) /* for each command line switch */
    {

        switch (c) /* which switch? */
        {

            case 'd': /* request for sound device? */

                device = optarg; /* yes, save the sound device */
                break;

            case 'i': /* request for input file name? */

                in_name = optarg; /* yes, save the input file name */
                break;

            case 'v':

                (void) printf ("%s\n", rcsid); /* print the version */
                (void) printf ("%s\n", copyright); /* print the copyright */
                optind = argc; /* force argument error */
                retval = EARGS; /* assume not enough arguments */

            default: /* illegal switch? */

                optind = argc; /* force argument error */
                retval = EARGS; /* assume not enough arguments */
                break;
        }

    }

    if (retval == NOERROR) /* enough arguments? */
    {
        retval = EIOPEN; /* assume error opening file */

        if ((infile = (in_name == (char *) 0) ? infile : open (in_name, O_RDWR)) >= 0) /* open the input file */
        {
            retval = NOERROR; /* assume no error */
            ref = inbuffer; /* reset the character reference in input buffer */
            *ref = '\0'; /* terminate the record */

            while ((retval == NOERROR) && ((cnt_in = read (infile, &inchar, sizeof (char))) == sizeof (char))) /* read characters from the input file */
            {

                if ((inchar == 'q') || (inchar == 'Q')) /* quit command? */
                {
                    break;
                }

                retval = EOVRFL; /* assume error overflow buffer */

                if (ref < sentinel) /* buffer overflow? */
                {
                    *ref = inchar; /* save the character in the input buffer */
                    ref ++; /* prepare for next character reference in input buffer */
                    *ref = '\0'; /* terminate the record; may overwrite the sentinel '\0' */
                    retval = NOERROR; /* assume no error */

                    if (inchar == '\n') /* character an EOL? */
                    {

                        if ((fields = strtoken (inbuffer, parsebuffer, token, WS_SEPARATORS)) != 0) /* parse the record into fields, skip null records */
                        {
                            tmp = atof (token[0]); /* save the amplitude */

                            if ((tmp > (double) 0.0) && tmp <= (double) 1.0)
                            {
                                amplitude = tmp; /* save the amplitude */
                            }

                        }

                        else if (inbuffer[0] == '\n') /* null record? */
                        {
                            amplitude = (double) 0.21780216733572844168; /* amplitude to generate, defaults to -15 dBFS */
                        }

                        ref = inbuffer; /* reset the character reference in input buffer */
                        *ref = '\0'; /* terminate the record */
                        retval = white_gen (device, infile, amplitude); /* generate white noise through the sound card */
                    }

                }

            }

            if (infile != STDIN_FILENO) /* input file open? */
            {

                if (close (infile) == 0) /* close the input file */
                {
                    infile = STDIN_FILENO; /* reset the input file descriptor */
                }

            }

        }

        retval = (cnt_in == 0) ? NOERROR : retval; /* a count of zero, and error reading input file was an EOF or ^D, a normal exit */
    }

    print_message (retval); /* print any error messages */
    exit (retval); /* exit with the error value */

#ifdef LINT

    return (0); /* for lint formalities */

#endif

}

/*

Print any error messages.

static void print_message (int retval);

I) Data structures:

    A) The help_message array is an array of character stings, one per
       line to be printed for help.

    B) The error_message array is an array of character strings, one
       line per error; the error_message array is implicitly addressed
       by the value integer retval, which specifies the error to be
       printed.

II) Function execution:

    A) Depending on the value of the integer retval:

        1) If retval is zero, print nothing-normal/successful program
           exit.

        2) Else if retval is unity, print help.

        3) Else retval is not zero or unity, it is an error code, print
           the corresponding error message.

Returns nothing.

*/

#ifdef __STDC__

static void print_message (int retval)

#else

static void print_message (retval)
int retval;

#endif

{
    size_t help_ctr; /* help_message line counter */

    switch (retval) /* which return value */
    {

        case 0: /* program ended without errors, print nothing */

            break;

        case 1: /* program ended with a request for help, or argument error, print help */

            for (help_ctr = 0; help_ctr < (sizeof (help_message) / sizeof (char *)); help_ctr ++) /* for each line of help */
            {
                (void) printf ("%s", help_message[help_ctr]); /* print the line */
            }

            break;

        default: /* an error that was not a request for help, print the error */

            (void) fprintf (stderr, "%s", error_message[retval]);
            break;

    }

}

/*

Parse a record based on sequential delimiters.

int strtoken (char *string, char *parse_array, char **parse, const char *delim);

I) Parse a character array, string, into an array, parse_array, using
consecutive characters from delim as field delimiters, point the
character pointers, token, to the beginning of each field.

Returns the number of fields parsed.

*/

#ifdef __STDC__

static int strtoken (char *string, char *parse_array, char **parse, const char *delim)

#else

static int strtoken (string, parse_array, parse, delim)
char *string;
char *parse_array;
char **parse;
char *delim;

#endif

{
    int tokens = 0;

    (void) strcpy (parse_array, string); /* copy the string */

    parse[tokens] = strtok (parse_array, delim); /* get the 1st field */

    while (parse[tokens] != 0) /* get the remaining fields */
    {
        parse[++ tokens] = strtok ((char *) 0, delim);
    }

    return (tokens); /* return the number of tokens parsed */
}

/*

Generate white noise through the sound card.

static int white_gen (char *device, int infile, double amplitude);

I) Data structure:

    1) device is the sound device to use for the white noise.

    2) infile is the input file to read white noise amplitude.

    3) amplitude is the amplitude of the white noise.

Returns any error, NOERROR on success.

*/

#ifdef __STDC__

static int white_gen (char *device, int infile, double amplitude)

#else

static int white_gen (device, infile, amplitude)
char *device;
int infile;
double amplitude;

#endif

{
    short val; /* value of white noise signal sample, (always the floor (sample_value)) */

    int retval = NOERROR, /* return value, assume no error */
        tmp, /* temporary variable */
        pending_ret, /* pending amplitude flag, 0 = no, 1 = yes, -1 = error */
        cnt, /* sample counter */
        fd = -1; /* sound device file descriptor */

    double sample_value = (double) 0.0; /* the value of white noise signal sample */

    struct timeval timeout; /* time value structure for select(2) determination of pending amplitude */

    fd_set fds; /* select () struct for determination of pending amplitude */

    if (retval == NOERROR) /* enough arguments? */
    {
        retval = EOPEN; /* assume error opening sound device */

        if ((fd = open (device, O_WRONLY, (mode_t) 0)) != -1) /* open the sound device */
        {

            /* set sample format to 16 bits */

            tmp = AFMT_S16_NE; /* native 16 bits */
            retval = EIOF; /* assume error setting sample format */

            if (ioctl (fd, SNDCTL_DSP_SETFMT, &tmp) != -1) /* native 16 bits */
            {

                if (tmp == AFMT_S16_NE) /* 16 bits supported? */
                {

                    /* set number of channels */

                    tmp = 1;
                    retval = EION; /* assume error setting number of channels */

                    if (ioctl (fd, SNDCTL_DSP_CHANNELS, &tmp) != -1) /* mono */
                    {

                        if (tmp == 1) /* mono supported? */
                        {

                            /* set the sample rate */

                            retval = EIOS; /* assume error setting sample rate */

                            if (ioctl (fd, SNDCTL_DSP_SPEED, &sample_rate) != -1)
                            {
                                retval = NOERROR; /* assume no error */
                                cnt = sample_rate; /* set the sample counter for one second */

                                while (retval == NOERROR) /* for each time sample */
                                {
                                    sample_value = (((double) rand () / (double) RAND_MAX) - (double) 0.5) * (double) 65534.0; /* generate a random number between -32767 and +32767 */
                                    val = (short) floor (sample_value * amplitude); /* value of white noise signal sample, (always the floor (sample_value)) */
                                    retval = EWRITE; /* error writing to sound device */

                                    if (write (fd, &val, sizeof (short)) == (ssize_t) sizeof (short)) /* write the record to the sound device */
                                    {
                                        retval = NOERROR; /* assume no error */

                                        if (cnt -- < 0) /* one second passed? */
                                        {
                                            cnt = sample_rate; /* set the sample counter for one second */
                                            timeout.tv_sec = (long) 0; /* time value structure for select(2) determination of pending amplitude, seconds */
                                            timeout.tv_usec = (long) 1; /* time value structure for select(2) determination of pending amplitude, microseconds; place holder, only-most system will not time to one microsecond */
                                            FD_ZERO (&fds); /* null the select () struct for select(2) determination of pending amplitude */
                                            FD_SET (infile, &fds); /* install the select () struct for select(2) determination of pending amplitude */

                                            if ((pending_ret = select (infile + 1, &fds, (fd_set *) 0, (fd_set *) 0, &timeout)) != 0) /* check for pending data on infile, i.e., determine if pending amplitude */
                                            {
                                                retval = EISEL; /* assume error selecting input file */

                                                if (pending_ret == 1) /* pending amplitude? */
                                                {
                                                    retval = NOERROR; /* assume no error */
                                                    break; /* interrupt the current white noise, and do the next amplitude */
                                                }

                                            }

                                        }

                                    }

                                }

                            }

                        }

                    }

                }

            }

            if (close (fd) == -1) /* close the sound device */
            {

                if (retval == NOERROR) /* any previous errors? */
                {
                    retval = ECLOSE; /* assume error closing sound device */
                }

            }

        }

    }

    return (retval); /* return any errors */
}
